import { request } from '@@/plugin-request/request';
import { stringify } from 'qs';

/**
 * 地区设备数量Top5
 * @param param
 */
export async function queryAreaData(param: object) {
  return request(`/web/v1/statistic/area/chart?${stringify(param)}`);
}

/**
 * 获取用户数
 */
export async function queryUserData() {
  return request(`/web/v1/statistic/user`);
}

/**
 * 设备统计
 */
export async function queryDeviceData() {
  return request(`/web/v1/statistic/device`);
}

/**
 * 设备运行时长统计
 */
export async function queryDeviceRunTime() {
  return request(`/web/v1/statistic/device/run_time`);
}

/**
 * 设备增长趋势
 * @param param
 */
export async function queryDeviceChart(param: object) {
  return request(`/web/v1/statistic/device/chart?${stringify(param)}`);
}

/**
 * 用户增长趋势
 * @param param
 */
export async function queryUserChart(param: object) {
  return request(`/web/v1/statistic/user/chart?${stringify(param)}`);
}

/**
 * 查询家列表信息
 */
export async function queryHomeInfo() {
  return request(`/web/v1/statistic/home_info`);
}

/**
 * 查询地图数据
 */
export async function queryMapJson() {
  return request(`/web/v1/map_jsons/user`);
}

/**
 * 获取有数据的区域
 */
export async function queryProvinceData() {
  return request(`/web/v1/statistic/province/chart`);
}
